==> blancoNLpackGenerator-0.1.2-src.zip: src/blanco/nlpack/generator/task/valueobject/BlancoNLpackGeneratorParsePropertiesProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.nlpack.generator.task.valueobject;

/**
 * NX [BlancoNLpackGeneratorParsePropertiesProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoNLpackGeneratorParsePropertiesProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [sourcedir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͂̃fBNgB
     */
    private String fSourcedir;

    /**
     * tB[h [targetfile]
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̖͂|󌋉ʃO(ResultDetailt@C`)̃t@CB
     */
    private String fTargetfile;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [sourcedir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͂̃fBNgB
     *
     * @param argSourcedir tB[h[sourcedir]Ɋi[l
     */
    public void setSourcedir(final String argSourcedir) {
        fSourcedir = argSourcedir;
    }

    /**
     * tB[h[sourcedir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͂̃fBNgB
     *
     * @return tB[h[sourcedir]Ɋi[Ăl
     */
    public String getSourcedir() {
        return fSourcedir;
    }

    /**
     * tB[h [targetfile]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̖͂|󌋉ʃO(ResultDetailt@C`)̃t@CB
     *
     * @param argTargetfile tB[h[targetfile]Ɋi[l
     */
    public void setTargetfile(final String argTargetfile) {
        fTargetfile = argTargetfile;
    }

    /**
     * tB[h[targetfile]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̖͂|󌋉ʃO(ResultDetailt@C`)̃t@CB
     *
     * @return tB[h[targetfile]Ɋi[Ăl
     */
    public String getTargetfile() {
        return fTargetfile;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorParsePropertiesProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",sourcedir=" + fSourcedir);
        buf.append(",targetfile=" + fTargetfile);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoNLpackGenerator-0.1.20-src.zip: src/blanco/nlpack/generator/task/valueobject/BlancoNLpackGeneratorParsePropertiesProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.nlpack.generator.task.valueobject;

/**
 * NX [BlancoNLpackGeneratorParsePropertiesProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoNLpackGeneratorParsePropertiesProcessInput {
    /**
     * verbose[hœ삳邩ǂB
     *
     * tB[h: [verbose]B
     * ftHg: [false]B
     */
    private boolean fVerbose = false;

    /**
     * ͂̃fBNgB
     *
     * tB[h: [sourcedir]B
     */
    private String fSourcedir;

    /**
     * o̖͂|󌋉ʃO(ResultDetailt@C`)̃t@CB
     *
     * tB[h: [targetfile]B
     */
    private String fTargetfile;

    /**
     * tB[h [verbose] ̒lݒ肵܂B
     *
     * tB[h̐: [verbose[hœ삳邩ǂB]B
     *
     * @param argVerbose tB[h[verbose]ɐݒ肷lB
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h [verbose] ̒l擾܂B
     *
     * tB[h̐: [verbose[hœ삳邩ǂB]B
     * ftHg: [false]B
     *
     * @return tB[h[verbose]擾lB
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [sourcedir] ̒lݒ肵܂B
     *
     * tB[h̐: [͂̃fBNgB]B
     *
     * @param argSourcedir tB[h[sourcedir]ɐݒ肷lB
     */
    public void setSourcedir(final String argSourcedir) {
        fSourcedir = argSourcedir;
    }

    /**
     * tB[h [sourcedir] ̒l擾܂B
     *
     * tB[h̐: [͂̃fBNgB]B
     *
     * @return tB[h[sourcedir]擾lB
     */
    public String getSourcedir() {
        return fSourcedir;
    }

    /**
     * tB[h [targetfile] ̒lݒ肵܂B
     *
     * tB[h̐: [o̖͂|󌋉ʃO(ResultDetailt@C`)̃t@CB]B
     *
     * @param argTargetfile tB[h[targetfile]ɐݒ肷lB
     */
    public void setTargetfile(final String argTargetfile) {
        fTargetfile = argTargetfile;
    }

    /**
     * tB[h [targetfile] ̒l擾܂B
     *
     * tB[h̐: [o̖͂|󌋉ʃO(ResultDetailt@C`)̃t@CB]B
     *
     * @return tB[h[targetfile]擾lB
     */
    public String getTargetfile() {
        return fTargetfile;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorParsePropertiesProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",sourcedir=" + fSourcedir);
        buf.append(",targetfile=" + fTargetfile);
        buf.append("]");
        return buf.toString();
    }
}
